`genetic.data` <-
function(data, groups, loci, base, basetows=NULL, mix, mixtows=NULL, gmethod = c("pbayes","rmprior")[1], tol = 0.0001)
{
#check if selected groups for base, basetows, mix, mixtows are actually in the data
        if(!all(is.element(levels(base[[groups]]),levels(data[[groups]])))){
           print("One or more base groups is not present in the data.")
        } else if(!all(is.element(levels(mix[[groups]]),levels(data[[groups]])))){
           print("One or more mix groups is not present in the data.")
        } else if(!is.null(basetows) && !all(is.element(basetows,levels(data[[groups]])))){
           print("One or more basetow groups is not present in the data.")
        } else if(!is.null(mixtows) && !all(is.element(mixtows,levels(data[[groups]])))){
           print("One or more mixtow groups is not present in the data.")
        }

#subset base with basetows
        if(!is.null(basetows)){
           base<-base[is.element(as.character(base[[groups]]),basetows), ] #does not drop elements!
           base[[groups]]<-drop.levels(base[[groups]])
        } else {
           base[[groups]]<-drop.levels(base[[groups]])
        }


#subset mix with mixtows
        if(!is.null(mixtows)){
           mix<-mix[is.element(as.character(mix[[groups]]),mixtows), ]
           mix[[groups]]<-drop.levels(mix[[groups]])
        } else {


           mix[[groups]]<-drop.levels(mix[[groups]])
        }

        n.base.groups <- length(unique(base[[groups]]))
        n.mix.groups <- length(unique(mix[[groups]]))

#can there be 1 obs for basetows or mixtows i.e. check for min data there as well?

        basecheck<-summary(base[[groups]])
        mixcheck<-summary(mix[[groups]])

        for(i in 1:n.base.groups){
	         if(basecheck[[i]]<3){
		   return(print(paste("Error, base group ", names(basecheck[i]), " has <3 observations")))
		   }
        }
        for(m in 1:n.mix.groups){

               if(mixcheck[[m]]<3){
		   return(print(paste("Error, mix group ", names(mixcheck[m]), "  has <3 observations")))
               }
        }

#check if loci exist in data, base and mix
        for(g in 1:length(loci)){
           if(!length(grep(paste(loci[[g]], "_", sep=""),names(data)))==2){
              print(paste("Locus ", loci[[g]]," does not exist in data")) #line break after!
           }
           if(!length(grep(paste(loci[[g]], "_", sep=""),names(mix)))==2){
              print(paste("Locus ", loci[[g]]," does not exist in mix groups")) #line break after!
           }
           if(!length(grep(paste(loci[[g]], "_", sep=""),names(base)))==2){
              print(paste("Locus ", loci[[g]]," does not exist in base groups")) #line break after!
           }
        }

  lenloci<-length(loci) #set length of loop
  out.data<-list(NULL) #create empty list()

  for(g in 1:lenloci) {

        #set Locus from loci list
        Locus<-paste(loci[g], "_", sep="")

        basedata <- base[order(base[[groups]]),  ] #must use new variale name to avoid overwriting 'base' so 'basedata'
        unique.groups <- unique(ugroups <- as.character(basedata[[groups]])) #ugroups to avoid multiple variables called 'groups'

        num.unique.groups <- length(unique.groups)
        Locus.posn <- grep(Locus, names(mix))
        Groups.posn <- grep(groups, names(basedata)) 
        N.mixtows <- length(mixtows)
        out1 <- out2 <- out3 <- vector("list", length = N.mixtows)
        basedata <- basedata[, c(Groups.posn, Locus.posn)]
        alleles <- c(basedata[[2]], basedata[[3]])
        all.genotypes <- basedata[, 2:3]
        for(i in 1:N.mixtows) {
                assign(paste("mix", i, sep = ""), mix[mix[[groups]] == mixtows[i], Locus.posn])
                out1[[i]] <- get(paste("mix", i, sep = ""))
                names(out1)[i] <- paste("mix", i, sep = "")
                alleles <- c(alleles, out1[[i]][[1]], out1[[i]][[2]])
                all.genotypes <- rbind(all.genotypes, out1[[i]])
        }
        alleles <- sort(unique(alleles))
        base.gen <- basedata[order.base <- order(basedata[, 2],basedata[, 3]), 2:3]
        ogroups <- ugroups[order.base] #ogroups to avoid multiples variables called 'groups'

        total.alleles.base.chrom1 <- total.alleles.base.chrom2 <- matrix(0, num.unique.groups, length(alleles))
        total.alleles.groups <- as.character(basedata[, 1])
        names.genotypes <- paste(char.pad.zeroes(base.gen[, 1]), char.pad.zeroes(base.gen[, 2]), sep = ":")
        unique.names.genotypes <- unique(names.genotypes)
        #augment for unique genotypes in mix sample
        all.genotypes <- all.genotypes[order(all.genotypes[, 1],all.genotypes[, 2]),  ]
        names.all.genotypes <- paste(char.pad.zeroes(all.genotypes[, 1]), char.pad.zeroes(all.genotypes[, 2]), sep = ":")
        unique.names.all.genotypes <- unique(names.all.genotypes)
        base.genotypes <- matrix(0, num.unique.groups, length(unique.names.all.genotypes))
        for(i in 1:num.unique.groups) {
                group.alleles <- table(names.genotypes[ogroups == unique.groups[i]], names.genotypes[ogroups == unique.groups[i]])
                group.alleles.names <- unlist(dimnames(group.alleles)[1])
                group.alleles.names.pos <- match(group.alleles.names, unique.names.all.genotypes)
                base.genotypes[i, group.alleles.names.pos] <- diag(group.alleles)
                alleles.chrom1 <- table(basedata[total.alleles.groups == unique.groups[i], 2], basedata[total.alleles.groups == unique.groups[i], 2])
                alleles.chrom2 <- table(basedata[total.alleles.groups == unique.groups[i], 3], basedata[total.alleles.groups == unique.groups[i], 3])
                total.alleles.base.chrom1[i, is.element(alleles, unlist(dimnames(alleles.chrom1)[1]))] <- diag(alleles.chrom1)
                total.alleles.base.chrom2[i, is.element(alleles, unlist(dimnames(alleles.chrom2)[1]))] <- diag(alleles.chrom2)
        }
        mult.homo.hetero <- rep(1, dim(base.genotypes)[2])
        mult.homo.hetero[substring(unique.names.all.genotypes, 1, 3) != substring(unique.names.all.genotypes, 5, 7)] <- 2
        index.base.HWE <- matrix(0, 2, dim(base.genotypes)[2])
        index.base.HWE[1,  ] <- match(as.numeric(substring(unique.names.all.genotypes, 1, 3)), alleles)
        index.base.HWE[2,  ] <- match(as.numeric(substring(unique.names.all.genotypes, 5, 7)), alleles)
        for(i in 1:N.mixtows) {
                assign(paste("mix", i, ".genotypes", sep = ""), paste(char.pad.zeroes(out1[[i]][, 1]), char.pad.zeroes(out1[[i]][, 2]), sep = ":"))
                out2[[i]] <- get(paste("mix", i, ".genotypes", sep = ""))
                assign(paste("position.mix", i, ".genotypes", sep = ""), match(out2[[i]], unique.names.all.genotypes))
                out3[[i]] <- get(paste("position.mix", i, ".genotypes", sep = ""))
                names(out3)[i] <- paste("position.mix", i, ".genotypes", sep = "")
        }

        xx<-c(list(unique.groups = unique.groups, alleles = alleles, total.alleles.base = total.alleles.base.chrom1 + total.alleles.base.chrom2, 
                unique.names.genotypes = unique.names.all.genotypes, mult.homo.hetero = mult.homo.hetero, base.genotypes = base.genotypes, 	index.base.HWE= index.base.HWE), out3, list(Locus = Locus))

     #pass xx to format.genetic.data()
     if(g==1){
        out.data<-format.genetic.data(xx)
     } else {
        mid<-format.genetic.data(xx)

        #Length of first elements changes! Therefore, generated from N.mixtows
        first<-4+N.mixtows #As there are 3 elements calculated in common, N.mixtows changes - add 1 for the next element space
        out.data<-c(out.data,mid[first:length(mid)]) #drop first N.mixtows elements since they are repetitive
     }

  }

#alpha.x prior inits added here

  if(gmethod == "pbayes") {
       out.alpha<-pbayes(out.data, tol)
  } else {
       out.alpha<-rmprior(out.data)
  }

  out.data<-c(out.data,out.alpha)
  return(out.data)
}

