`genetic.model` <-
function(genetic.data, loci, mixparameters=NULL)
{

    n.mix <- grep("N.mix", names(genetic.data))
    G <- length(n.mix)
    L <- length(loci)

#Default Parameters
    lnmix<-length(n.mix)
    params <- vector("character", length = (lnmix*2))

    for(i in 1:lnmix){
        params[i] <- paste("T", i, sep="")
        params[i+lnmix] <- paste("P", i, sep="")
	}

#Create mixmodel.txt text file in local directory	
    x.out <- paste("model;", "\n", "{")
    cat(x.out, "\n", file="mixmodel.txt", append=FALSE)

#Mixture sample
    for(i in 1:G){
      
          x1 <- paste("for( i in 1 : ", names(genetic.data[n.mix[i]]), ")  {", sep="")
          x2 <- paste("T", i, "[i] ~ dcat(P", i, "[])", sep="")
          x.out <- paste(x1,'\n',x2)
          
          cat(x.out, "\n", file="mixmodel.txt", append=TRUE)

       for(m in 1:L) {
          x3 <- paste(paste("pi.ind", i, loci[m], sep = "."), "[i]<-", sep="")
          x4 <- paste("pi.", loci[m], "[T", i, "[i],", paste("mix.posn", i, loci[m], sep="."), "[1,i]]", sep="")
          x5 <- paste("*pi.", loci[m], "[T", i, "[i],", paste("mix.posn", i, loci[m], sep="."), "[2,i]]", sep="")
          x6 <- paste(paste("*HWE.mult", i, loci[m], sep="."), "[i]", sep="")
          x.out <- paste(x3,x4,x5,x6)

          x7 <- paste(paste("ind", i, loci[m], sep="."), "[i]~dbern(pi.ind.", paste(i, loci[m], sep="."), "[i])", sep="")
          
          cat(x.out, "\n", x7, "\n", file="mixmodel.txt", append=TRUE)

       }

       x.out <- paste("}")
       cat(x.out, "\n", file="mixmodel.txt", append=TRUE)
    }

#Training Sample

       x.out <- paste("for( j in 1 : G) {", sep="")
       cat(x.out, "\n", file="mixmodel.txt", append=TRUE)

    for(n in 1:L){
       x.out <- paste(paste("base", loci[n], sep="."), "[j, 1:M.", loci[n], "]~dmulti(pi.", loci[n], "[j,],NTrain.gen[j])", sep="")
       cat(x.out, "\n", file="mixmodel.txt", append=TRUE)
    }
       x.out <- paste("}")
       cat(x.out, "\n", file="mixmodel.txt", append=TRUE)

#Priors

    for(n in 1:G){
      x.out <- paste("P", n, "[1:G] ~ ddirch(alpha[])", sep="")
      cat(x.out, "\n", file="mixmodel.txt", append=TRUE)
    }

      x.out <- paste("for(g in 1:G) {")
      cat(x.out, "\n", file="mixmodel.txt", append=TRUE)

      for(f in 1:L){

		x1 <- paste("for(kk in 1:M.", loci[f], ") {", sep="")
            x2 <- paste("pi.", loci[f], "[g,kk]<-pi.r.", loci[f], "[g,kk]/sum(pi.r.", loci[f], "[g,])", sep="")
		x3 <-	paste("pi.r.", loci[f], "[g,kk]~dgamma(alpha.", loci[f], "[kk],1.0)I(1.0E-5,)", sep="")
            x4 <- paste(" }")
            x.out <- paste(x1, x2, x3, x4, sep="\n")

            cat(x.out, "\n", file="mixmodel.txt", append=TRUE)

       }

       x.out <- paste("}")
       cat(x.out, "\n", file="mixmodel.txt", append=TRUE)

#Posterior Predictive Diagnostic

       x.out <- paste("for( j in 1 : G) {", sep="")
       cat(x.out, "\n", file="mixmodel.txt", append=TRUE)

    for(n in 1:L){
       x.out <- paste(paste("rep", loci[n], sep="."), "[j, 1:M.", loci[n], "]~dmulti(pi.", loci[n], "[j,],NTrain.gen[j])", sep="")
       cat(x.out, "\n", file="mixmodel.txt", append=TRUE)
    }
       x.out <- paste("}")
       cat(x.out, "\n", file="mixmodel.txt", append=TRUE)

 #New additions.  S.J. Smith 08/07/2009
 
       x.out <- paste("for( i in 1 : G) {", sep="")
       cat(x.out, "\n", file="mixmodel.txt", append=TRUE)

      for(f in 1:L){
      x1 <- paste("for(j in 1:M.", loci[f], ") {", sep="")
       x1.1<-paste("pi.",loci[f],"[i,j]*NTrain.gen[i]",sep="")
        x2<-paste("Xrep.",loci[f],"[i,j]<-pow(rep.",loci[f],"[i,j] - ",x1.1,",2)/(",x1.1,")",sep="")
         x3<-paste("Xobs.",loci[f],"[i,j]<-pow(base.",loci[f],"[i,j] - ",x1.1,",2)/(",x1.1,")",sep="")
          x4 <- paste("}")
           x5<-paste("genpredcheck",f,"[i]<-step(sum(Xrep.",loci[f],"[i,])-sum(Xobs.",loci[f],"[i,]))",sep="")
            x.out <- paste(x1, x2, x3, x4, x5, sep="\n")
       cat(x.out, "\n", file="mixmodel.txt", append=TRUE)
        }
       x.out <- paste("}")
       cat(x.out, "\n", file="mixmodel.txt", append=TRUE)
       

# End of new additions.  S.J. Smith
       
#end of model
    x.out <- paste("}")
    cat(x.out, "\n", file="mixmodel.txt", append=TRUE)

#Default Parameters
    if(is.null(mixparameters)){
    return(params)
	}
	
}

