`mix.fish` <-
function(data, method=c("combined","otolith","genetic")[1], groups, loci=NULL, otolith.var=NULL, mixparameters=NULL, base, 
basetows=NULL, mix, mixtows=NULL, gmethod = c("pbayes","rmprior")[1], type= c("random", "fixed")[1], max.prob = 0.9, 
n.chains = 2, n.iter=200, n.burnin=floor(n.iter/2), n.thin=max(1, floor(n.chains * (n.iter - n.burnin) / n.sims)), n.sims = 1000, 
debug=FALSE, tol = 0.0001)

{
#prepare data, inits, parameters (defaults), and model
  if(method == "combined") {
       data.otolith<-otolith.data(data, groups, otolith.var, base, basetows, mix, mixtows) 
       data.genetic<-genetic.data(data, groups, loci, base, basetows, mix, mixtows, gmethod=gmethod, tol=tol)
       mixdata<-mergelist(data.otolith, data.genetic)
       mixinits<-otolith.inits(mixdata, type, n.chains, max.prob=max.prob) #takes care of all variables
     if(is.null(mixparameters)){
       mixparameters<-combined.model(mixdata, loci, mixparameters)   #also creates mixmodel.bug file
     } else combined.model(mixdata, loci, mixparameters)
  } else if(method == "otolith") {
       mixdata<-otolith.data(data, groups, otolith.var, base, basetows, mix, mixtows) 
       mixinits<-otolith.inits(mixdata, type, n.chains, max.prob=max.prob)
     if(is.null(mixparameters)){
       mixparameters<-otolith.model(mixdata, mixparameters) #also creates mixmodel.bug file
     } else otolith.model(mixdata, mixparameters)
  } else if(method == "genetic") {
       mixdata<-genetic.data(data, groups, loci, base, basetows, mix, mixtows, gmethod=gmethod, tol=tol)
       mixinits<-genetic.inits(mixdata, type, n.chains, max.prob=max.prob)
     if(is.null(mixparameters)){
        mixparameters<-genetic.model(mixdata, loci, mixparameters) #also creates mixmodel.bug file
     } else genetic.model(mixdata, loci, mixparameters)
  }

 
#Run WinBUGS
#Modified 15/06/2009 S.J. Smith
	bayes<-bugs(mixdata, mixinits, mixparameters, model.file="mixmodel.txt", n.chains=n.chains, 
	n.iter=n.iter, debug=debug, n.burnin=n.burnin,
    n.thin=n.thin, n.sims=n.sims,
	bugs.directory="c:/Program Files/WinBUGS14/",
	program=c("WinBUGS", "OpenBUGS", "winbugs", "openbugs"),
	working.directory=getwd())

return(bayes)
}

