`otolith.data` <-
function(data, groups, otolith.var, base, basetows=NULL, mix, mixtows=NULL)
{

#check if selected groups for base, basetows, mix, mixtows are actually in the data
        if(!all(is.element(levels(base[[groups]]),levels(data[[groups]])))){
           print("One or more base groups is not present in the data.")
        } else if(!all(is.element(levels(mix[[groups]]),levels(data[[groups]])))){
           print("One or more mix groups is not present in the data.")
        } else if(!is.null(basetows) && !all(is.element(basetows,levels(data[[groups]])))){
           print("One or more basetow groups is not present in the data.")
        } else if(!is.null(mixtows) && !all(is.element(mixtows,levels(data[[groups]])))){
           print("One or more mixtow groups is not present in the data.")
        }

#subset base with basetows
        if(!is.null(basetows)){
           base<-base[is.element(as.character(base[[groups]]),basetows), ] #does not drop elements!
           base[[groups]]<-drop.levels(base[[groups]]) #drops only levels missing from 'groups'
        } else {
           base[[groups]]<-drop.levels(base[[groups]])
        }

#subset mix with mixtows
        if(!is.null(mixtows)){
           mix<-mix[is.element(as.character(mix[[groups]]),mixtows), ]
           mix[[groups]]<-drop.levels(mix[[groups]])
        } else {
           mix[[groups]]<-drop.levels(mix[[groups]])
        }

        n.base.groups <- length(unique(base[[groups]]))
        n.mix.groups <- length(unique(mix[[groups]]))

#can there be 1 obs for basetows or mixtows i.e. check for min data there as well?
        basecheck<-summary(base[[groups]])
        mixcheck<-summary(mix[[groups]])

        for(i in 1:n.base.groups){
	         if(basecheck[[i]]<3){
		   return(print(paste("Error, base group ", names(basecheck[i]), " has <3 observations")))
		   }
        }
        for(m in 1:n.mix.groups){
               if(mixcheck[[m]]<3){
		   return(print(paste("Error, mix group ", names(mixcheck[m]), "  has <3 observations")))
               }
        }

#check if variables exist in data
        if(!all(is.element(otolith.var,names(data)))){
           var.diff<-setdiff(otolith.var,intersect(otolith.var,names(data)))
           print(paste("Variable ", var.diff," does not exist")) #insert line break after!
        }


        ngroups<-n.base.groups


#This logical statement does not drop factors, but converts them to numeric.
        if(is.factor(base[[groups]])){
                T.groups <- as.numeric(as.factor(T.group.names <- as.character(base[[groups]])))} else {
                T.groups <- as.numeric(as.factor(base[[groups]]))
		}
        N.cols <- (1:dim(base)[2])[is.element(names(base), otolith.var)]
        y.base <- base[, N.cols]
        y.base <- y.base[order(T.groups),  ]
        y.base <- strip.names(y.base)
        T.groups <- sort(T.groups)
        mixtows <- sort(mixtows)
        N.mixtows <- length(mixtows)
        out1 <- out2 <- vector("list", length = N.mixtows)
        out3 <- vector("list", length = ngroups)
        for(i in 1:N.mixtows) {
                mixit <- mix[mix[groups] == mixtows[i], N.cols]
                assign(paste("y.mix", i, sep = ""), mixit)
                out1[[i]] <- get(paste("y.mix", i, sep = ""))
                names(out1)[i] <- paste("y.mix", i, sep = "")
                assign(paste("N.mix", i, sep = ""), dim(get(paste("y.mix", i, sep = "")))[1])
                out2[[i]] <- get(paste("N.mix", i, sep = ""))[1]
                names(out2)[i] <- paste("N.mix", i, sep = "")
        }
        out1 <- sapply(out1, strip.names,simplify=FALSE) #unnecesary with attributes()<-NULL
        num.vars <- length(N.cols)
        T.R <- diag(num.vars)
        for(i in 1:ngroups) {
                assign(paste("y.mean", i, sep = ""), as.vector(apply(y.base[T.groups == i,  ], 2, mean)))
                out3[[i]] <- get(paste("y.mean", i, sep = ""))
                names(out3)[i] <- paste("y.mean", i, sep = "")
        }
         
#		NTrain <- as.list(diag(table(T.groups, T.groups)))
		 
        return(as.list(c(list(R = T.R, NTrain = diag(table(T.groups, T.groups))), out2, list(Ntrain.oto = dim(base)[1], 
        G = ngroups, V = num.vars, Train.oto = T.groups, alpha = rep(1/ngroups, ngroups)), out3, out1, 
        list(y.base = y.base)))) #NEW required return() for package building

}

#NTrain = sample size for each group
#Ntrain.oto = sum NTrain
#Train.oto = series of indices for original groups
